# CallbackInfo

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**authorization** | **str** | string to be passed as auth header to client webhook url | [optional]
**client_data** | **object** | arbitrary json that is passed back to the user upon request completion | [optional]
**url** | **str** | url to post results to upon request completion |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

